@@ -1038,8 +1038,11 @@ sub _looks_like_expression {
 
     return 0 unless defined $expr;
 
-    return 1 if $expr =~ /[\-*\/%]/;
     return 1 if $expr =~ /\b(?:floor|ceil|round|tonumber)\b/;
+    return 0 if $expr =~ /^\s*[\{\[]/;
+    return 0 if $expr =~ /^[A-Za-z_]\w*\s*\(/;
+    return 1 if $expr =~ /[\-*\/%]/;
+    return 1 if $expr =~ /(?:==|!=|>=|<=|>|<|\band\b|\bor\b)/i;
 
     return 0;
 }
